.. _aoa:

Anatomy Of The Application
==========================

This document is meant to give an overview of the Glances interface.

Legend:

=========== ============
``GREEN``   ``OK``
``BLUE``    ``CAREFUL``
``MAGENTA`` ``WARNING``
``RED``     ``CRITICAL``
=========== ============

.. note::
    Only stats with colored background will be shown in the alert view.

.. toctree::
   :maxdepth: 2

   header
   quicklook
   cpu
   gpu
   memory
   load
   network
   connections
   wifi
   ports
   diskio
   fs
   irq
   folders
   cloud
   raid
   smart
   sensors
   hddtemp
   ps
   containers
   amps
   events
   actions
